@@ -13,6 +13,7 @@ from .crypto import ripemd160_sha256
 from .exceptions import SerializationError, PasswordError
 from hashlib import md5
 
+
 class ProtobufWallet(object):
 
     def __init__(self, data: Any) -> None:
@@ -40,10 +41,9 @@ class ProtobufWallet(object):
         else:
             data = base64.b64decode(data)
 
-
         return cls(data)
 
-    def parse(self, passphrase: Optional[str]=None):
+    def parse(self, passphrase: Optional[str] = None):
         if self.raw_data[:8] == b'Salted__':
             if passphrase is None:
                 raise PasswordError
@@ -60,13 +60,14 @@ class ProtobufWallet(object):
                 iv = newdata[32:32 + AES.block_size]
                 cipher = AES.new(key, AES.MODE_CBC, iv)
                 try:
-                    padded_plain = cipher.decrypt(self.raw_data[AES.block_size:])
+                    padded_plain = cipher.decrypt(
+                        self.raw_data[AES.block_size:])
                     pad_len = padded_plain[-1]
                     if isinstance(pad_len, str):
                         pad_len = ord(pad_len)
                     plain_data = padded_plain[:-pad_len]
                     self.wallet.parse(plain_data)
-                except:
+                except BaseException:
                     raise PasswordError
         else:
             self.wallet.parse(self.raw_data)
@@ -92,21 +93,28 @@ class ProtobufWallet(object):
                 if k.type == 3:
                     mnemonic = k.secret_bytes.decode()
                     deterministic_seed = k.deterministic_seed.hex()
-                    self.mnemonics.append({"mnemonic": mnemonic, "deterministic_seed": deterministic_seed})
+                    self.mnemonics.append(
+                        {"mnemonic": mnemonic, "deterministic_seed": deterministic_seed})
                 elif k.type == 4 or k.type == 1:
-                    creation_timestamp = arrow.get(int(k.creation_timestamp)).isoformat()
+                    creation_timestamp = arrow.get(
+                        int(k.creation_timestamp)).isoformat()
                     keydict = {"creation_timestamp": creation_timestamp}
                     if k.type == 4:
                         deterministic_key = k.deterministic_key.to_dict()
-                        deterministic_key["chainCode"] = base64.b64decode(deterministic_key['chainCode']).hex()
+                        deterministic_key["chainCode"] = base64.b64decode(
+                            deterministic_key['chainCode']).hex()
                         keydict["deterministic_key"] = deterministic_key
                     prefix = bytes([self.default_wifnetwork])
-                    pubkey = base58.b58encode_check(prefix + ripemd160_sha256(k.public_key)).decode()
+                    pubkey = base58.b58encode_check(
+                        prefix + ripemd160_sha256(k.public_key)).decode()
                     keydict["pubkey"] = pubkey
                     if len(k.secret_bytes) > 0:
-                        privkey_prefix = int.to_bytes(self.default_wifnetwork + 128, 1, byteorder='big')
-                        compressed = base58.b58encode_check(privkey_prefix + k.secret_bytes).decode()
-                        uncompressed = base58.b58encode_check(privkey_prefix + k.secret_bytes + b'\x01').decode()
+                        privkey_prefix = int.to_bytes(
+                            self.default_wifnetwork + 128, 1, byteorder='big')
+                        compressed = base58.b58encode_check(
+                            privkey_prefix + k.secret_bytes).decode()
+                        uncompressed = base58.b58encode_check(
+                            privkey_prefix + k.secret_bytes + b'\x01').decode()
                         keydict["compressed_private_key"] = compressed
                         keydict["uncompressed_private_key"] = uncompressed
                     keydict["label"] = k.label
@@ -116,18 +124,23 @@ class ProtobufWallet(object):
                 self.lastblockhash = self.wallet.last_seen_block_hash.hex()
             if hasattr(self.wallet, 'transaction'):
                 for t in self.wallet.transaction:
+                    txjson = t.to_json()
+                    print(txjson)
                     tx = t.to_dict()
                     tx["hash"] = base64.b64decode(tx['hash']).hex()
-                    tx["updatedAt"] = arrow.get(int(tx["updatedAt"])).isoformat()
+                    tx["updatedAt"] = arrow.get(
+                        int(tx["updatedAt"])).isoformat()
                     txinputs = []
                     for txinput in tx['transactionInput']:
                         inputdict = {}
                         if 'transactionOutPointHash' in txinput.keys():
-                            inputdict['transactionOutPointHash'] = base64.b64decode(txinput['transactionOutPointHash']).hex()
+                            inputdict['transactionOutPointHash'] = base64.b64decode(
+                                txinput['transactionOutPointHash']).hex()
                         if 'transactionOutPointIndex' in txinput.keys():
                             inputdict['transactionOutPointIndex'] = txinput['transactionOutPointIndex']
                         if 'scriptBytes' in txinput.keys():
-                            inputdict['scriptBytes'] = base64.b64decode(txinput['scriptBytes']).hex()
+                            inputdict['scriptBytes'] = base64.b64decode(
+                                txinput['scriptBytes']).hex()
                         txinputs.append(inputdict)
                     tx['transactionInput'] = txinputs
                     txoutputs = []
@@ -135,11 +148,12 @@ class ProtobufWallet(object):
                         outputdict = {}
                         if 'spentByTransactionHash' in txoutput.keys():
                             outputdict['spentByTransactionHash'] = base64.b64decode(
-                                    txoutput['spentByTransactionHash']).hex()
+                                txoutput['spentByTransactionHash']).hex()
                         if 'spentByTransactionIndex' in txoutput.keys():
                             outputdict['spentByTransactionIndex'] = txoutput['spentByTransactionIndex']
                         if 'scriptBytes' in txoutput.keys():
-                            outputdict['scriptBytes'] = base64.b64decode(txoutput['scriptBytes']).hex()
+                            outputdict['scriptBytes'] = base64.b64decode(
+                                txoutput['scriptBytes']).hex()
                         if 'value' in txoutput.keys():
                             outputdict['value'] = txoutput['value']
                         txoutputs.append(outputdict)
@@ -156,7 +170,11 @@ class ProtobufWallet(object):
             self.keypairs = self.wallet.to_dict()['key']
 
     def dump_all(self, filepath: Optional[str] = None) -> Dict:
-        output_items = {"keys": self.keypairs, "tx": self.txes, "mnemonics": self.mnemonics, "description": self.description}
+        output_items = {
+            "keys": self.keypairs,
+            "tx": self.txes,
+            "mnemonics": self.mnemonics,
+            "description": self.description}
         if filepath is not None:
             with open(filepath, "a") as ft:
                 ft.write(json.dumps(output_items, sort_keys=True, indent=4))
@@ -172,12 +190,3 @@ class ProtobufWallet(object):
             with open(filepath, "a") as ft:
                 ft.write(json.dumps(output_keys, sort_keys=True, indent=4))
         return output_keys
-
-
-
-
-
-
-
-
-
